//go:build wasm

package function

import "github.com/scaleway/scaleway-cli/v2/core"

func functionDeploy() *core.Command {
	return nil
}
